Thanks, I installed most of them, though with some changes as some fixes need to be installed upstream first, and others didn't seem to be needed ("obsolescent" is a word and has a different meaning from "obsolete"). Plus I fixed some nearby grammar issues.

Attached is what I installed.
diff --git a/ChangeLog b/ChangeLog
index 4bbdb9ccf3..9345067bb7 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -113356,7 +113356,7 @@
 2008-04-11  Simon Josefsson  <[email protected]>
 
 	* lib/gc-gnulib.c: On Windows, use CryptGenRandom from CSP instead
-	of attempting to use non-existing /dev/*random.  Based on patch
+	of attempting to use nonexistent /dev/*random.  Based on patch
 	from Adam Strzelecki <[email protected]> in
 	<http://lists.gnu.org/r/help-gsasl/2008-02/msg00000.html>.
 
diff --git a/Makefile b/Makefile
index 9cc7979557..6915fa5dbd 100644
--- a/Makefile
+++ b/Makefile
@@ -276,7 +276,7 @@ COPYRIGHT_TZ = UTC0
 # Also exclude doc/INSTALL*, since they too are generated.
 # Also adjust template-style files that must start with a single
 # (the current) year number in some places.
-# Also adjust version-etc.c and and gendocs.sh.
+# Also adjust version-etc.c and gendocs.sh.
 update-copyright:
 	export TZ='$(COPYRIGHT_TZ)';					\
 	exempt=$$(mktemp);						\
diff --git a/STATUS-libposix b/STATUS-libposix
index 9b74be4c96..e95a2a5dd1 100644
--- a/STATUS-libposix
+++ b/STATUS-libposix
@@ -63,7 +63,7 @@ Bruno Haible says:
   <https://lists.gnu.org/r/bug-gnulib/2010-10/msg00291.html>
   <https://lists.gnu.org/r/bug-gnulib/2010-10/msg00308.html
 
-3) iconv_open's file file list
+3) iconv_open's file list
   <https://lists.gnu.org/r/bug-gnulib/2010-10/msg00282.html>
 
   Discussion:
diff --git a/build-aux/bootstrap b/build-aux/bootstrap
index 8c68e96d43..93e000d155 100755
--- a/build-aux/bootstrap
+++ b/build-aux/bootstrap
@@ -340,7 +340,7 @@ check_versions() {
     # Handle the still-experimental Automake-NG programs specially.
     # They remain named as the mainstream Automake programs ("automake",
     # and "aclocal") to avoid gratuitous incompatibilities with
-    # pre-existing usages (by, say, autoreconf, or custom autogen.sh
+    # preexisting usages (by, say, autoreconf, or custom autogen.sh
     # scripts), but correctly identify themselves (as being part of
     # "GNU automake-ng") when asked their version.
     case $app in
diff --git a/build-aux/depcomp b/build-aux/depcomp
index ce5c2f7bcb..ecee3e7883 100755
--- a/build-aux/depcomp
+++ b/build-aux/depcomp
@@ -198,7 +198,7 @@ gcc3)
 
 gcc)
 ## Note that this doesn't just cater to obsolete pre-3.x GCC compilers.
-## but also to in-use compilers like IMB xlc/xlC and the HP C compiler.
+## but also to in-use compilers like IBM xlc/xlC and the HP C compiler.
 ## (see the conditional assignment to $gccflag above).
 ## There are various ways to get dependency output from gcc.  Here's
 ## why we pick this rather obscure method:
diff --git a/build-aux/vcs-to-changelog.py b/build-aux/vcs-to-changelog.py
index f41c4aa2e0..946798f250 100755
--- a/build-aux/vcs-to-changelog.py
+++ b/build-aux/vcs-to-changelog.py
@@ -28,12 +28,12 @@ ProjectQuirks or a subclass of the same.  The definition of the ProjectQuirks
 class is below and it specifies the properties that the project must set to
 ensure correct parsing of its contents.
 
-Among other things, ProjectQurks specifies the VCS to read from; the default is
+Among other things, ProjectQuirks specifies the VCS to read from; the default is
 assumed to be git.  The script then studies the VCS log and for each change,
 list out the nature of changes in the constituent files.
 
 Each file type may have parser frontends that can read files and construct
-objects that may be compared to determine the minimal changes that occured in
+objects that may be compared to determine the minimal changes that occurred in
 each revision.  For files that do not have parsers, we may only know the nature
 of changes at the top level depending on the information that the VCS stores.
 
diff --git a/build-aux/vcstocl/frontend_c.py b/build-aux/vcstocl/frontend_c.py
index bb3fee8b56..926d81b775 100644
--- a/build-aux/vcstocl/frontend_c.py
+++ b/build-aux/vcstocl/frontend_c.py
@@ -206,7 +206,7 @@ class CompositeParser(ExprParser):
             if 'typedef' in cur:
                 name = re.sub(r'.*}\s*(\w+);$', r'\1', cur)
             else:
-                name= '<anoymous>'
+                name= '<anonymous>'
 
         ctype = found.group(1)
 
@@ -457,7 +457,7 @@ class Frontend:
         ''' Parse a preprocessor directive.
 
         In case a preprocessor condition (i.e. if/elif/else), create a new code
-        block to nest code into and in other cases, identify and add entities suchas
+        block to nest code into and in other cases, identify and add entities such as
         include files, defines, etc.
 
         - OP is the string array for the file
@@ -649,7 +649,7 @@ class Frontend:
     def consolidate_tree_blocks(self, tree):
         ''' Consolidate common macro conditional blocks.
 
-        Get macro conditional blocks at the same level but scatterred across the
+        Get macro conditional blocks at the same level but scattered across the
         file together into a single common block to allow for better comparison.
         '''
         # Nothing to do for non-nesting blocks.
diff --git a/doc/gnulib-tool.texi b/doc/gnulib-tool.texi
index 03f7cacbd5..3737ed6943 100644
--- a/doc/gnulib-tool.texi
+++ b/doc/gnulib-tool.texi
@@ -179,7 +179,7 @@ extra effort to create self-contained tarballs, and it may disturb some
 mechanism the maintainer applies to the sources.  For these reasons,
 this option is generally discouraged.
 
-@code{gnulib-tool} will overwrite any pre-existing files, in
+@code{gnulib-tool} will overwrite any preexisting files, in
 particular @file{Makefile.am}.  It is also possible to separate the
 generated @file{Makefile.am} content (for building the gnulib library)
 into a separate file, say @file{gnulib.mk}, that can be included by your
diff --git a/doc/lib-symbol-visibility.texi b/doc/lib-symbol-visibility.texi
index ec948a37ad..be5e0863fc 100644
--- a/doc/lib-symbol-visibility.texi
+++ b/doc/lib-symbol-visibility.texi
@@ -116,7 +116,7 @@ macOS,
 AIX with gcc or xlclang.
 @end itemize
 @noindent
-It is not supprted on
+It is not supported on
 @itemize @bullet
 @item
 Other compilers on ELF platforms or AIX,
diff --git a/doc/posix-functions/aligned_alloc.texi b/doc/posix-functions/aligned_alloc.texi
index e78ca16f9e..7180cf3c12 100644
--- a/doc/posix-functions/aligned_alloc.texi
+++ b/doc/posix-functions/aligned_alloc.texi
@@ -32,7 +32,7 @@ that do not crash even if the AddressSanitizer bug is present:
 @itemize
 @item
 The Gnulib module @code{alignalloc} provides a portable function
-@code{alignalloc} that is a near-substitute for for glibc
+@code{alignalloc} that is a near-substitute for glibc
 @code{aligned_alloc}, except that the result must be freed
 with @code{alignfree} rather than plain @code{free}.
 
diff --git a/doc/posix-functions/ctime.texi b/doc/posix-functions/ctime.texi
index bb6abb23a8..2ac56cb524 100644
--- a/doc/posix-functions/ctime.texi
+++ b/doc/posix-functions/ctime.texi
@@ -27,7 +27,7 @@ not required to be thread safe.  Implementations of @code{ctime}
 typically write the timestamp into static buffer.  If two threads
 call @code{ctime} at roughly the same time, you might end up with the
 wrong date in one of the threads, or some undefined string.  There is
-a re-entrant interface @code{ctime_r}.
+a reentrant interface @code{ctime_r}.
 @item
 Native Windows platforms (mingw, MSVC) support only a subset of time
 zones supported by GNU or specified by POSIX@.  @xref{tzset}.
diff --git a/doc/posix-functions/mbrtowc.texi b/doc/posix-functions/mbrtowc.texi
index bcba3f4c53..163a374ea2 100644
--- a/doc/posix-functions/mbrtowc.texi
+++ b/doc/posix-functions/mbrtowc.texi
@@ -28,7 +28,7 @@ This function does not put the state into non-initial state when parsing an
 incomplete multibyte character on some platforms:
 AIX 7.2.
 @item
-This function stores a wide character when when parsing an incomplete multibyte
+This function stores a wide character when parsing an incomplete multibyte
 character on some platforms:
 MSVC 14.
 @item
diff --git a/lib/argp-parse.c b/lib/argp-parse.c
index a147a1e71b..dfc4351f9b 100644
--- a/lib/argp-parse.c
+++ b/lib/argp-parse.c
@@ -248,7 +248,7 @@ struct parser
   /* LONG_OPTS is the array of getop long option structures for the union of
      all the groups of options.  */
   struct option *long_opts;
-  /* OPT_DATA is the getopt data used for the re-entrant getopt.  */
+  /* OPT_DATA is the getopt data used for the reentrant getopt.  */
   struct _getopt_data opt_data;
 
   /* States of the various parsing groups.  */
diff --git a/lib/argp.h b/lib/argp.h
index 7de939a2a1..404a631ca7 100644
--- a/lib/argp.h
+++ b/lib/argp.h
@@ -407,7 +407,7 @@ struct argp_state
    unknown option is present, ARGP_ERR_UNKNOWN is returned; if some parser
    routine returned a non-zero value, it is returned; otherwise 0 is
    returned.  This function may also call exit unless the ARGP_NO_HELP flag
-   is set.  INPUT is a pointer to a value to be passed in to the parser.  */
+   is set.  INPUT is a pointer to a value to be passed into the parser.  */
 extern error_t argp_parse (const struct argp *__restrict __argp,
                            int /*argc*/, char **__restrict /*argv*/,
                            unsigned __flags, int *__restrict __arg_index,
diff --git a/lib/bitset.h b/lib/bitset.h
index bb6596f7fe..93146626a8 100644
--- a/lib/bitset.h
+++ b/lib/bitset.h
@@ -383,10 +383,10 @@ void bitset_stats_enable (void);
 /* Disable bitset stats gathering.  */
 void bitset_stats_disable (void);
 
-/* Read bitset stats file of accummulated stats.  */
+/* Read bitset stats file of accumulated stats.  */
 void bitset_stats_read (const char *file_name);
 
-/* Write bitset stats file of accummulated stats.  */
+/* Write bitset stats file of accumulated stats.  */
 void bitset_stats_write (const char *file_name);
 
 /* Dump bitset stats.  */
diff --git a/lib/des.c b/lib/des.c
index 3aad65170b..46d701822e 100644
--- a/lib/des.c
+++ b/lib/des.c
@@ -50,7 +50,7 @@
  *     unsigned char key[8];
  *     unsigned char plaintext[8];
  *     unsigned char ciphertext[8];
- *     unsigned char recoverd[8];
+ *     unsigned char recovered[8];
  *     gl_des_ctx context;
  *
  *     // Fill 'key' and 'plaintext' with some data
@@ -63,7 +63,7 @@
  *     des_ecb_encrypt(&context, plaintext, ciphertext);
  *
  *     // To recover the original plaintext from ciphertext use:
- *     des_ecb_decrypt(&context, ciphertext, recoverd);
+ *     des_ecb_decrypt(&context, ciphertext, recovered);
  *
  *
  * Triple-DES Example
@@ -73,10 +73,10 @@
  *     unsigned char key3[8];
  *     unsigned char plaintext[8];
  *     unsigned char ciphertext[8];
- *     unsigned char recoverd[8];
+ *     unsigned char recovered[8];
  *     gl_3des_ctx context;
  *
- *     // If you would like to use two 64bit keys, fill 'key1' and'key2'
+ *     // If you would like to use two 64bit keys, fill 'key1' and 'key2'
  *     // then setup the encryption context:
  *     gl_3des_set2keys(&context, key1, key2);
  *
@@ -87,7 +87,7 @@
  *     gl_3des_ecb_encrypt(&context, plaintext, ciphertext);
  *
  *     // Decrypting ciphertext to recover the plaintext with Triple-DES
- *     gl_3des_ecb_decrypt(&context, ciphertext, recoverd);
+ *     gl_3des_ecb_decrypt(&context, ciphertext, recovered);
  */
 
 
diff --git a/lib/dfa.c b/lib/dfa.c
index d54aab40fd..f1bab73059 100644
--- a/lib/dfa.c
+++ b/lib/dfa.c
@@ -3263,9 +3263,9 @@ build_state (state_num s, struct dfa *d, unsigned char uc)
 /* Multibyte character handling sub-routines for dfaexec.  */
 
 /* Consume a single byte and transit state from 's' to '*next_state'.
-   This function is almost same as the state transition routin in dfaexec.
-   But state transition is done just once, otherwise matching succeed or
-   reach the end of the buffer.  */
+   This is almost the same as the state transition routine in dfaexec.
+   But the state transition is done just once; otherwise, matching succeeds or
+   we reach the end of the buffer.  */
 static state_num
 transit_state_singlebyte (struct dfa *d, state_num s, unsigned char const **pp)
 {
diff --git a/lib/fchownat.c b/lib/fchownat.c
index 8d00ae587c..c8a016088f 100644
--- a/lib/fchownat.c
+++ b/lib/fchownat.c
@@ -1,5 +1,5 @@
 /* This function serves as replacement for a missing fchownat function,
-   as well as a work around for the fchownat bug in glibc-2.4:
+   as well as a workaround for the fchownat bug in glibc-2.4:
     <https://lists.ubuntu.com/archives/ubuntu-users/2006-September/093218.html>
    when the buggy fchownat-with-AT_SYMLINK_NOFOLLOW operates on a symlink, it
    mistakenly affects the symlink referent, rather than the symlink itself.
diff --git a/lib/fts.c b/lib/fts.c
index 3fffb45d70..884b84a5a1 100644
--- a/lib/fts.c
+++ b/lib/fts.c
@@ -1804,7 +1804,7 @@ fts_stat(FTS *sp, register FTSENT *p, bool follow)
 
         /*
          * If doing a logical walk, or application requested FTS_FOLLOW, do
-         * a stat(2).  If that fails, check for a non-existent symlink.  If
+         * a stat(2).  If that fails, check for a nonexistent symlink.  If
          * fail, set the errno from the stat call.
          */
         int flags = follow ? 0 : AT_SYMLINK_NOFOLLOW;
diff --git a/lib/hash.h b/lib/hash.h
index be42e5af6a..54d3f22f69 100644
--- a/lib/hash.h
+++ b/lib/hash.h
@@ -204,7 +204,7 @@ extern Hash_table *hash_xinitialize (size_t candidate,
   _GL_ATTRIBUTE_RETURNS_NONNULL;
 
 /* Make all buckets empty, placing any chained entries on the free list.
-   Apply the user-specified function data_freer (if any) to the datas of any
+   Apply the user-specified function data_freer (if any) to the data of any
    affected entries.  */
 extern void hash_clear (Hash_table *table);
 
diff --git a/lib/mbmemcasecoll.c b/lib/mbmemcasecoll.c
index 552dbbbd72..6f4acb7e77 100644
--- a/lib/mbmemcasecoll.c
+++ b/lib/mbmemcasecoll.c
@@ -159,7 +159,7 @@ mbmemcasecoll (const char *s1, size_t s1len, const char *s2, size_t s2len,
   t1 = memory;
   t2 = memory + t1len + 1;
 
-  /* Csae-fold the two argument strings.  */
+  /* Case-fold the two argument strings.  */
   if (MB_CUR_MAX > 1)
     {
       t1len = apply_towlower (s1, s1len, t1, t1len);
diff --git a/lib/parse-datetime.y b/lib/parse-datetime.y
index 18c9ebef3c..f926f4d84c 100644
--- a/lib/parse-datetime.y
+++ b/lib/parse-datetime.y
@@ -1638,7 +1638,7 @@ debug_strftime (struct tm const *tm, char *buf, int n)
     date:        normalized time: '(Y-M-D) 2006-04-02 03:45:00'
     date:                                             __
     date:      possible reasons:
-    date:        non-existing due to daylight-saving time;
+    date:        nonexistent due to daylight-saving time;
     date:        numeric values overflow;
     date:        missing timezone;
  */
@@ -1690,7 +1690,7 @@ debug_mktime_not_ok (struct tm const *tm0, struct tm const *tm1,
 
   dbg_printf (_("     possible reasons:\n"));
   if (dst_shift)
-    dbg_printf (_("       non-existing due to daylight-saving time;\n"));
+    dbg_printf (_("       nonexistent due to daylight-saving time;\n"));
   if (!eq_mday && !eq_month)
     dbg_printf (_("       invalid day/month combination;\n"));
   dbg_printf (_("       numeric values overflow;\n"));
diff --git a/lib/regcomp.c b/lib/regcomp.c
index 8947839685..1f6a131107 100644
--- a/lib/regcomp.c
+++ b/lib/regcomp.c
@@ -905,7 +905,7 @@ init_word_char (re_dfa_t *dfa)
       bitset_word_t bits3 = 0x07fffffe;
       if (BITSET_WORD_BITS == 64)
 	{
-	  /* Pacify gcc -Woverflow on 32-bit platformns.  */
+	  /* Pacify gcc -Woverflow on 32-bit platforms.  */
 	  dfa->word_char[0] = bits1 << 31 << 1 | bits0;
 	  dfa->word_char[1] = bits3 << 31 << 1 | bits2;
 	  i = 2;
diff --git a/lib/rename.c b/lib/rename.c
index 4722f13a12..aa3afd8768 100644
--- a/lib/rename.c
+++ b/lib/rename.c
@@ -360,7 +360,7 @@ rpl_rename (char const *src, char const *dst)
 # if (RENAME_TRAILING_SLASH_SOURCE_BUG || RENAME_DEST_EXISTS_BUG        \
       || RENAME_HARD_LINK_BUG)
   /* If the only bug was that a trailing slash was allowed on a
-     non-existing file destination, as in Solaris 10, then we've
+     nonexistent file destination, as in Solaris 10, then we've
      already covered that situation.  But if there is any problem with
      a trailing slash on an existing source or destination, as in
      Solaris 9, or if a directory can overwrite a symlink, as on
diff --git a/lib/setlocale.c b/lib/setlocale.c
index d3b453c2c3..c976e9abf7 100644
--- a/lib/setlocale.c
+++ b/lib/setlocale.c
@@ -1574,7 +1574,7 @@ setlocale_improved (int category, const char *locale)
                            For LC_COLLATE, the application should use the locale
                            properties kCFLocaleCollationIdentifier,
                            kCFLocaleCollatorIdentifier.
-                           For LC_MONETARY, the applicationshould use the locale
+                           For LC_MONETARY, the application should use the locale
                            properties kCFLocaleCurrencySymbol,
                            kCFLocaleCurrencyCode.
                            But since most applications don't have macOS specific
diff --git a/lib/sigsegv.in.h b/lib/sigsegv.in.h
index 40b453e67b..7db6c0df39 100644
--- a/lib/sigsegv.in.h
+++ b/lib/sigsegv.in.h
@@ -214,7 +214,7 @@ typedef void (*stackoverflow_handler_t) (int emergency, stackoverflow_context_t
  * Installs a stack overflow handler.
  * The extra_stack argument is a pointer to a pre-allocated area used as a
  * stack for executing the handler. It typically comes from a static variable
- * or from heap-allocated memoty; placing it on the main stack may fail on
+ * or from heap-allocated memory; placing it on the main stack may fail on
  * some operating systems.
  * Its size, passed in extra_stack_size, should be sufficiently large.  The
  * following code determines an appropriate size:
diff --git a/lib/stackvma.c b/lib/stackvma.c
index 1224b7b07c..0f245fba1b 100644
--- a/lib/stackvma.c
+++ b/lib/stackvma.c
@@ -112,7 +112,7 @@ simple_is_near_this (uintptr_t addr, struct vma_struct *vma)
      - On all platforms, if some other thread is doing memory allocations or
        deallocations between two read() calls, there is a high risk that the
        result of these two read() calls don't fit together, and as a
-       consequence we will parse gargage and either omit some VMAs or return
+       consequence we will parse garbage and either omit some VMAs or return
        VMAs with nonsensical addresses.
    So use mmap(), and ignore the resulting VMA.
    The stack-allocated buffer cannot be too large, because this can be called
@@ -939,7 +939,7 @@ struct callback_locals
 {
   uintptr_t address;
   struct vma_struct *vma;
-  /* The stack appears as multiple adjacents segments, therefore we
+  /* The stack appears as multiple adjacent segments, therefore we
      merge adjacent segments.  */
   uintptr_t curr_start, curr_end;
 # if STACK_DIRECTION < 0
@@ -1050,7 +1050,7 @@ struct callback_locals
 {
   uintptr_t address;
   struct vma_struct *vma;
-  /* The stack appears as multiple adjacents segments, therefore we
+  /* The stack appears as multiple adjacent segments, therefore we
      merge adjacent segments.  */
   uintptr_t curr_start, curr_end;
 # if STACK_DIRECTION < 0
@@ -2160,7 +2160,7 @@ struct callback_locals
 {
   uintptr_t address;
   struct vma_struct *vma;
-  /* The stack appears as three adjacents segments, therefore we
+  /* The stack appears as three adjacent segments, therefore we
      merge adjacent segments.  */
   uintptr_t curr_start, curr_end;
 # if STACK_DIRECTION < 0
diff --git a/lib/sys_file.in.h b/lib/sys_file.in.h
index dbce799973..3919e57651 100644
--- a/lib/sys_file.in.h
+++ b/lib/sys_file.in.h
@@ -43,7 +43,7 @@
 # define LOCK_EX 2       /* Exclusive lock.  */
 # define LOCK_UN 8       /* Unlock.  */
 
-/* Can be OR'd in to one of the above.  */
+/* Can be OR'd into one of the above.  */
 # define LOCK_NB 4       /* Don't block when locking.  */
 #endif
 
diff --git a/lib/timevar.h b/lib/timevar.h
index cafa02407e..057adb8a79 100644
--- a/lib/timevar.h
+++ b/lib/timevar.h
@@ -35,7 +35,7 @@ extern "C" {
    system.
 
    Timing variables are defined using the DEFTIMEVAR macro in
-   timevar.def.  Each has an enumeral identifier, used when referring
+   timevar.def.  Each has an identifier of type timevar_id_t, used to refer
    to the timing variable in code, and a character string name.
 
    Timing variables can be used in two ways:
diff --git a/lib/wchar.in.h b/lib/wchar.in.h
index 69fa2f8f59..75f3ed21ff 100644
--- a/lib/wchar.in.h
+++ b/lib/wchar.in.h
@@ -1199,7 +1199,7 @@ _GL_WARN_ON_USE (wcsrchr, "wcsrchr is unportable - "
 #endif
 
 
-/* Return the length of the initial segmet of WCS which consists entirely
+/* Return the length of the initial segment of WCS which consists entirely
    of wide characters not in REJECT.  */
 #if @GNULIB_WCSCSPN@
 # if !@HAVE_WCSCSPN@
@@ -1219,7 +1219,7 @@ _GL_WARN_ON_USE (wcscspn, "wcscspn is unportable - "
 #endif
 
 
-/* Return the length of the initial segmet of WCS which consists entirely
+/* Return the length of the initial segment of WCS which consists entirely
    of wide characters in ACCEPT.  */
 #if @GNULIB_WCSSPN@
 # if !@HAVE_WCSSPN@
diff --git a/m4/fsusage.m4 b/m4/fsusage.m4
index 88f3ca817c..724a863ac3 100644
--- a/m4/fsusage.m4
+++ b/m4/fsusage.m4
@@ -269,7 +269,7 @@ int check_f_blocks_size[sizeof fsd.f_blocks * CHAR_BIT <= 32 ? -1 : 1];
 
 # Check for SunOS statfs brokenness wrt partitions 2GB and larger.
 # If <sys/vfs.h> exists and struct statfs has a member named f_spare,
-# enable the work-around code in fsusage.c.
+# enable the workaround code in fsusage.c.
 AC_DEFUN([gl_STATFS_TRUNCATES],
 [
   AC_CACHE_CHECK([for statfs that truncates block counts],
diff --git a/m4/lib-link.m4 b/m4/lib-link.m4
index 653e34f8d1..5f8afae61a 100644
--- a/m4/lib-link.m4
+++ b/m4/lib-link.m4
@@ -224,7 +224,7 @@ AC_DEFUN([AC_LIB_LINKFLAGS_BODY],
     additional_libdir3=
   fi
   dnl Search the library and its dependencies in $additional_libdir and
-  dnl $LDFLAGS. Using breadth-first-seach.
+  dnl $LDFLAGS. Use breadth-first search.
   LIB[]NAME=
   LTLIB[]NAME=
   INC[]NAME=
diff --git a/modules/c-vsnprintf b/modules/c-vsnprintf
index eb62fd9691..8188a96d39 100644
--- a/modules/c-vsnprintf
+++ b/modules/c-vsnprintf
@@ -1,5 +1,5 @@
 Description:
-c_vsnprintf(): print formatted output from an stdarg argument listto a
+c_vsnprintf(): print formatted output from an stdarg argument list to a
 fixed length string in C locale
 
 Files:
diff --git a/pygnulib/GLConfig.py b/pygnulib/GLConfig.py
index a2392bf904..b99797d644 100644
--- a/pygnulib/GLConfig.py
+++ b/pygnulib/GLConfig.py
@@ -577,7 +577,7 @@ class GLConfig(object):
                             % type(file).__name__)
 
     def getFiles(self):
-        '''Return the list of the fileed files.'''
+        '''Return the list of files.'''
         return list(self.table['files'])
 
     def setFiles(self, files):
diff --git a/pygnulib/GLImport.py b/pygnulib/GLImport.py
index b7305eaacb..707c3e74d3 100644
--- a/pygnulib/GLImport.py
+++ b/pygnulib/GLImport.py
@@ -257,7 +257,7 @@ class GLImport(object):
             raise GLError(10, None)
 
         # Define GLImport attributes.
-        self.emiter = GLEmiter(self.config)
+        self.emitter = GLEmiter(self.config)
         self.filesystem = GLFileSystem(self.config)
         self.modulesystem = GLModuleSystem(self.config)
         self.moduletable = GLModuleTable(self.config,
@@ -490,7 +490,7 @@ class GLImport(object):
         modules = [ str(module)
                     for module in moduletable['base'] ]
         avoids = self.config['avoids']
-        emit += self.emiter.copyright_notice()
+        emit += self.emitter.copyright_notice()
         emit += '''#
 # This file represents the specification of how gnulib-tool is used.
 # It acts as a cache: It is written and read by gnulib-tool.
@@ -575,7 +575,7 @@ class GLImport(object):
         modules = [ str(module)
                     for module in moduletable['base'] ]
         emit += '# DO NOT EDIT! GENERATED AUTOMATICALLY!\n'
-        emit += self.emiter.copyright_notice()
+        emit += self.emitter.copyright_notice()
         emit += '''#
 # This file represents the compiled summary of the specification in
 # gnulib-cache.m4. It lists the computed macro invocations that need
@@ -593,7 +593,7 @@ AC_DEFUN([%s_EARLY],
   m4_pattern_allow([^gl_ES$])dnl a valid locale name
   m4_pattern_allow([^gl_LIBOBJS$])dnl a variable
   m4_pattern_allow([^gl_LTLIBOBJS$])dnl a variable\n''' % (configure_ac, macro_prefix)
-        emit += self.emiter.preEarlyMacros(True, '  ', moduletable['final'])
+        emit += self.emitter.preEarlyMacros(True, '  ', moduletable['final'])
         uses_subdirs = False
         for module in moduletable['main']:
             # Test whether there are some source files in subdirectories.
@@ -630,20 +630,20 @@ AC_DEFUN([%s_INIT],
         if auxdir != 'build-aux':
             replace_auxdir = True
         emit += '  gl_m4_base=\'%s\'\n' % m4base
-        emit += self.emiter.initmacro_start(macro_prefix)
+        emit += self.emitter.initmacro_start(macro_prefix)
         emit += '  gl_source_base=\'%s\'\n' % sourcebase
         if witness_c_macro:
             emit += '  m4_pushdef([gl_MODULE_INDICATOR_CONDITION], [%s])\n' % witness_c_macro
         # Emit main autoconf snippets.
-        emit += self.emiter.autoconfSnippets(moduletable['main'],
-                                             moduletable, 0, True, False, True, replace_auxdir)
+        emit += self.emitter.autoconfSnippets(moduletable['main'],
+                                              moduletable, 0, True, False, True, replace_auxdir)
         if witness_c_macro:
             emit += '  m4_popdef([gl_MODULE_INDICATOR_CONDITION])\n'
         emit += '  # End of code from modules\n'
-        emit += self.emiter.initmacro_end(macro_prefix)
+        emit += self.emitter.initmacro_end(macro_prefix)
         emit += '  gltests_libdeps=\n'
         emit += '  gltests_ltlibdeps=\n'
-        emit += self.emiter.initmacro_start('%stests' % macro_prefix)
+        emit += self.emitter.initmacro_start('%stests' % macro_prefix)
         emit += '  gl_source_base=\'%s\'\n' % testsbase
         # Define a tests witness macro that depends on the package.
         # PACKAGE is defined by AM_INIT_AUTOMAKE, PACKAGE_TARNAME is defined by
@@ -658,10 +658,10 @@ AC_DEFUN([%s_INIT],
         emit += '  m4_pushdef([gl_MODULE_INDICATOR_CONDITION], '
         emit += '[$gl_module_indicator_condition])\n'
         # Emit tests autoconf snippets.
-        emit += self.emiter.autoconfSnippets(moduletable['tests'],
-                                             moduletable, 0, True, True, True, replace_auxdir)
+        emit += self.emitter.autoconfSnippets(moduletable['tests'],
+                                              moduletable, 0, True, True, True, replace_auxdir)
         emit += '  m4_popdef([gl_MODULE_INDICATOR_CONDITION])\n'
-        emit += self.emiter.initmacro_end('%stests' % macro_prefix)
+        emit += self.emitter.initmacro_end('%stests' % macro_prefix)
         # _LIBDEPS and _LTLIBDEPS variables are not needed if this library is
         # created using libtool, because libtool already handles the dependencies.
         if not libtool:
@@ -674,8 +674,8 @@ AC_DEFUN([%s_INIT],
             emit += '  LIBTESTS_LIBDEPS="$gltests_libdeps"\n'
             emit += '  AC_SUBST([LIBTESTS_LIBDEPS])\n'
         emit += '])\n'
-        emit += self.emiter.initmacro_done(macro_prefix, sourcebase)
-        emit += self.emiter.initmacro_done('%stests' % macro_prefix, testsbase)
+        emit += self.emitter.initmacro_done(macro_prefix, sourcebase)
+        emit += self.emitter.initmacro_done('%stests' % macro_prefix, testsbase)
         emit += '''
 # This macro records the list of files which have been installed by
 # gnulib-tool and may be removed by future gnulib-tool invocations.
@@ -1135,9 +1135,9 @@ AC_DEFUN([%s_FILE_LIST], [\n''' % macro_prefix
         # Create library makefile.
         basename = joinpath(sourcebase, makefile_am)
         tmpfile = self.assistant.tmpfilename(basename)
-        emit, uses_subdirs = self.emiter.lib_Makefile_am(basename,
-                                                         self.moduletable['main'], self.moduletable, self.makefiletable,
-                                                         actioncmd, for_test)
+        emit, uses_subdirs = self.emitter.lib_Makefile_am(basename,
+                                                          self.moduletable['main'], self.moduletable, self.makefiletable,
+                                                          actioncmd, for_test)
         with codecs.open(tmpfile, 'wb', 'UTF-8') as file:
             file.write(emit)
         filename, backup, flag = self.assistant.super_update(basename, tmpfile)
@@ -1183,7 +1183,7 @@ AC_DEFUN([%s_FILE_LIST], [\n''' % macro_prefix
             # Create po makefile parameterization, part 1.
             basename = joinpath(pobase, 'Makevars')
             tmpfile = self.assistant.tmpfilename(basename)
-            emit = self.emiter.po_Makevars()
+            emit = self.emitter.po_Makevars()
             with codecs.open(tmpfile, 'wb', 'UTF-8') as file:
                 file.write(emit)
             filename, backup, flag = self.assistant.super_update(basename, tmpfile)
@@ -1205,7 +1205,7 @@ AC_DEFUN([%s_FILE_LIST], [\n''' % macro_prefix
             basename = joinpath(pobase, 'POTFILES.in')
             tmpfile = self.assistant.tmpfilename(basename)
             with codecs.open(tmpfile, 'wb', 'UTF-8') as file:
-                file.write(self.emiter.po_POTFILES_in(filetable['all']))
+                file.write(self.emitter.po_POTFILES_in(filetable['all']))
             basename = joinpath(pobase, 'POTFILES.in')
             filename, backup, flag = self.assistant.super_update(basename, tmpfile)
             if flag == 1:
@@ -1314,9 +1314,9 @@ AC_DEFUN([%s_FILE_LIST], [\n''' % macro_prefix
         if inctests:
             basename = joinpath(testsbase, makefile_am)
             tmpfile = self.assistant.tmpfilename(basename)
-            emit, uses_subdirs = self.emiter.lib_Makefile_am(basename,
-                                                             self.moduletable['tests'], self.moduletable, self.makefiletable,
-                                                             actioncmd, for_test)
+            emit, uses_subdirs = self.emitter.lib_Makefile_am(basename,
+                                                              self.moduletable['tests'], self.moduletable, self.makefiletable,
+                                                              actioncmd, for_test)
             with codecs.open(tmpfile, 'wb', 'UTF-8') as file:
                 file.write(emit)
             filename, backup, flag = self.assistant.super_update(basename, tmpfile)
diff --git a/pygnulib/GLInfo.py b/pygnulib/GLInfo.py
index 5e2eba54dd..cefb63a679 100644
--- a/pygnulib/GLInfo.py
+++ b/pygnulib/GLInfo.py
@@ -43,7 +43,7 @@ isdir = os.path.isdir
 # Define GLInfo class
 #===============================================================================
 class GLInfo(object):
-    '''This class is used to get fromatted information about gnulib-tool.
+    '''This class is used to get formatted information about gnulib-tool.
     This information is mainly used in stdout messages, but can be used
     anywhere else. The return values are not the same as for the module,
     but still depends on them.'''
diff --git a/pygnulib/GLTestDir.py b/pygnulib/GLTestDir.py
index 6eead9adb8..7a6ef559f1 100644
--- a/pygnulib/GLTestDir.py
+++ b/pygnulib/GLTestDir.py
@@ -80,7 +80,7 @@ class GLTestDir(object):
                 os.mkdir(self.testdir)
             except Exception as error:
                 raise GLError(19, self.testdir)
-        self.emiter = GLEmiter(self.config)
+        self.emitter = GLEmiter(self.config)
         self.filesystem = GLFileSystem(self.config)
         self.modulesystem = GLModuleSystem(self.config)
         self.assistant = GLFileAssistant(self.config)
@@ -354,11 +354,11 @@ class GLTestDir(object):
             os.mkdir(directory)
         destfile = joinpath(directory, 'Makefile.am')
         if single_configure:
-            emit, uses_subdirs = self.emiter.lib_Makefile_am(destfile, main_modules,
-                                                             moduletable, self.makefiletable, '', for_test)
+            emit, uses_subdirs = self.emitter.lib_Makefile_am(destfile, main_modules,
+                                                              moduletable, self.makefiletable, '', for_test)
         else:  # if not single_configure
-            emit, uses_subdirs = self.emiter.lib_Makefile_am(destfile, modules,
-                                                             moduletable, self.makefiletable, '', for_test)
+            emit, uses_subdirs = self.emitter.lib_Makefile_am(destfile, modules,
+                                                              moduletable, self.makefiletable, '', for_test)
         with codecs.open(destfile, 'wb', 'UTF-8') as file:
             file.write(emit)
         any_uses_subdirs = uses_subdirs
@@ -381,7 +381,7 @@ class GLTestDir(object):
         subdirs = [sourcebase, m4base]
         subdirs_with_configure_ac = list()
 
-        testsbase_appened = False
+        testsbase_append = False
         inctests = self.config.checkInclTestCategory(TESTS['tests'])
         if inctests:
             directory = joinpath(self.testdir, testsbase)
@@ -391,8 +391,8 @@ class GLTestDir(object):
                 # Create $testsbase/Makefile.am.
                 destfile = joinpath(directory, 'Makefile.am')
                 witness_macro = '%stests_WITNESS' % macro_prefix
-                emit, uses_subdirs = self.emiter.tests_Makefile_am(destfile,
-                                                                   tests_modules, self.makefiletable, witness_macro, for_test)
+                emit, uses_subdirs = self.emitter.tests_Makefile_am(destfile,
+                                                                    tests_modules, self.makefiletable, witness_macro, for_test)
                 with codecs.open(destfile, 'wb', 'UTF-8') as file:
                     file.write(emit)
             else:  # if not single_configure
@@ -400,8 +400,8 @@ class GLTestDir(object):
                 destfile = joinpath(directory, 'Makefile.am')
                 libtests = False
                 self.config.setLibtests(False)
-                emit, uses_subdirs = self.emiter.tests_Makefile_am(destfile,
-                                                                   modules, self.makefiletable, '', for_test)
+                emit, uses_subdirs = self.emitter.tests_Makefile_am(destfile,
+                                                                    modules, self.makefiletable, '', for_test)
                 with codecs.open(destfile, 'wb', 'UTF-8') as file:
                     file.write(emit)
                 # Viewed from the $testsbase subdirectory, $auxdir is different.
@@ -418,7 +418,7 @@ class GLTestDir(object):
                 emit += 'AC_PROG_CC\n'
                 emit += 'AC_PROG_INSTALL\n'
                 emit += 'AC_PROG_MAKE_SET\n'
-                emit += self.emiter.preEarlyMacros(False, '', modules)
+                emit += self.emitter.preEarlyMacros(False, '', modules)
                 if uses_subdirs:
                     emit += 'AM_PROG_CC_C_O\n\n'
                 snippets = list()
@@ -462,19 +462,19 @@ class GLTestDir(object):
                 emit += 'AC_DEFUN([gl_INIT], [\n'
                 replace_auxdir = True
                 emit += "gl_m4_base='../%s'\n" % m4base
-                emit += self.emiter.initmacro_start(macro_prefix)
+                emit += self.emitter.initmacro_start(macro_prefix)
                 # We don't have explicit ordering constraints between the various
                 # autoconf snippets. It's cleanest to put those of the library before
                 # those of the tests.
                 emit += "gl_source_base='../%s'\n" % sourcebase
-                emit += self.emiter.autoconfSnippets(modules,
-                                                     moduletable, 1, False, False, False,
-                                                     replace_auxdir)
+                emit += self.emitter.autoconfSnippets(modules,
+                                                      moduletable, 1, False, False, False,
+                                                      replace_auxdir)
                 emit += "gl_source_base='.'"
-                emit += self.emiter.autoconfSnippets(modules,
-                                                     moduletable, 2, False, False, False,
-                                                     replace_auxdir)
-                emit += self.emiter.initmacro_end(macro_prefix)
+                emit += self.emitter.autoconfSnippets(modules,
+                                                      moduletable, 2, False, False, False,
+                                                      replace_auxdir)
+                emit += self.emitter.initmacro_end(macro_prefix)
                 # _LIBDEPS and _LTLIBDEPS variables are not needed if this library is
                 # created using libtool, because libtool already handles the
                 # dependencies.
@@ -486,7 +486,7 @@ class GLTestDir(object):
                     emit += '  AC_SUBST([%s_LTLIBDEPS])\n' % libname_upper
                 emit += '])\n'
                 # FIXME use $sourcebase or $testsbase?
-                emit += self.emiter.initmacro_done(macro_prefix, sourcebase)
+                emit += self.emitter.initmacro_done(macro_prefix, sourcebase)
                 emit += '\ngl_INIT\n\n'
                 # Usually $testsbase/config.h will be a superset of config.h. Verify
                 # this by "merging" config.h into $testsbase/config.h; look out for gcc
@@ -505,7 +505,7 @@ class GLTestDir(object):
                 subdirs_with_configure_ac += [testsbase]
 
             subdirs += [testsbase]
-            testsbase_appened = True
+            testsbase_append = True
 
         # Create Makefile.am.
         emit = '## Process this file with automake to produce Makefile.in.\n\n'
@@ -535,7 +535,7 @@ class GLTestDir(object):
         emit += 'm4_pattern_allow([^gl_ES$])dnl a valid locale name\n'
         emit += 'm4_pattern_allow([^gl_LIBOBJS$])dnl a variable\n'
         emit += 'm4_pattern_allow([^gl_LTLIBOBJS$])dnl a variable\n'
-        emit += self.emiter.preEarlyMacros(False, '', modules)
+        emit += self.emitter.preEarlyMacros(False, '', modules)
         if any_uses_subdirs:
             emit += 'AM_PROG_CC_C_O\n'
         snippets = list()
@@ -582,19 +582,19 @@ class GLTestDir(object):
         else:  # auxdir == 'build-aux'
             replace_auxdir = False
         emit += 'gl_m4_base=\'%s\'\n' % m4base
-        emit += self.emiter.initmacro_start(macro_prefix)
+        emit += self.emitter.initmacro_start(macro_prefix)
         emit += 'gl_source_base=\'%s\'\n' % sourcebase
         if single_configure:
-            emit += self.emiter.autoconfSnippets(main_modules, moduletable,
-                                                 0, False, False, False, replace_auxdir)
+            emit += self.emitter.autoconfSnippets(main_modules, moduletable,
+                                                  0, False, False, False, replace_auxdir)
         else:  # if not single_configure
-            emit += self.emiter.autoconfSnippets(modules, moduletable,
-                                                 1, False, False, False, replace_auxdir)
-        emit += self.emiter.initmacro_end(macro_prefix)
+            emit += self.emitter.autoconfSnippets(modules, moduletable,
+                                                  1, False, False, False, replace_auxdir)
+        emit += self.emitter.initmacro_end(macro_prefix)
         if single_configure:
             emit += '  gltests_libdeps=\n'
             emit += '  gltests_ltlibdeps=\n'
-            emit += self.emiter.initmacro_start('%stests' % macro_prefix)
+            emit += self.emitter.initmacro_start('%stests' % macro_prefix)
             emit += '  gl_source_base=\'%s\'\n' % testsbase
             # Define a tests witness macro.
             emit += '  %stests_WITNESS=IN_GNULIB_TESTS\n' % macro_prefix
@@ -602,11 +602,11 @@ class GLTestDir(object):
             emit += '  gl_module_indicator_condition=$%stests_WITNESS\n' % macro_prefix
             emit += '  m4_pushdef([gl_MODULE_INDICATOR_CONDITION], '
             emit += '[$gl_module_indicator_condition])\n'
-            snippets = self.emiter.autoconfSnippets(tests_modules, moduletable,
-                                                    1, True, False, False, replace_auxdir)
+            snippets = self.emitter.autoconfSnippets(tests_modules, moduletable,
+                                                     1, True, False, False, replace_auxdir)
             emit += snippets.strip()
             emit += '  m4_popdef([gl_MODULE_INDICATOR_CONDITION])\n'
-            emit += self.emiter.initmacro_end('%stests' % macro_prefix)
+            emit += self.emitter.initmacro_end('%stests' % macro_prefix)
         # _LIBDEPS and _LTLIBDEPS variables are not needed if this library is
         # created using libtool, because libtool already handles the dependencies.
         if not libtool:
@@ -619,9 +619,9 @@ class GLTestDir(object):
             emit += '  LIBTESTS_LIBDEPS="$gltests_libdeps"\n'
             emit += '  AC_SUBST([LIBTESTS_LIBDEPS])\n'
         emit += '])\n'
-        emit += self.emiter.initmacro_done(macro_prefix, sourcebase)
+        emit += self.emitter.initmacro_done(macro_prefix, sourcebase)
         if single_configure:
-            emit += self.emiter.initmacro_done('%stests' % macro_prefix, testsbase)
+            emit += self.emitter.initmacro_done('%stests' % macro_prefix, testsbase)
         emit += '\ngl_INIT\n\n'
         if subdirs_with_configure_ac:
             if single_configure:
@@ -863,7 +863,7 @@ class GLMegaTestDir(object):
                 os.mkdir(self.megatestdir)
             except Exception as error:
                 raise GLError(19, self.megatestdir)
-        self.emiter = GLEmiter(self.config)
+        self.emitter = GLEmiter(self.config)
         self.filesystem = GLFileSystem(self.config)
         self.modulesystem = GLModuleSystem(self.config)
         self.assistant = GLFileAssistant(self.config)
diff --git a/pygnulib/__init__.py b/pygnulib/__init__.py
index ca3685be49..d0e308ba0e 100644
--- a/pygnulib/__init__.py
+++ b/pygnulib/__init__.py
@@ -31,5 +31,5 @@ Texinfo), assorted configuration scripts, and more. The goal is to provide all
 the common infrastructure needed by GNU packages.'''
 
 __copyright__ = '2012-2022 Free Software Foundation, Inc.'
-__author__ = 'Dmitriy Selyutin'
+__author__ = 'Dmitry Selyutin'
 __license__ = 'GNU GPLv3+'
diff --git a/pygnulib/constants.py b/pygnulib/constants.py
index 5bdd00f514..0e7700a6be 100644
--- a/pygnulib/constants.py
+++ b/pygnulib/constants.py
@@ -39,7 +39,7 @@ __author__ = \
         'Bruno Haible',
         'Paul Eggert',
         'Simon Josefsson',
-        'Dmitriy Selyutin',
+        'Dmitry Selyutin',
     ]
 __license__ = 'GNU GPLv3+'
 __copyright__ = '2002-2022 Free Software Foundation, Inc.'
diff --git a/tests/test-getlogin.h b/tests/test-getlogin.h
index e4ae3b8fb9..125c152152 100644
--- a/tests/test-getlogin.h
+++ b/tests/test-getlogin.h
@@ -49,7 +49,7 @@ test_getlogin_result (const char *buf, int err)
 
 #if defined __linux__
       /* On Linux, it is possible to set up a chroot environment in such a way
-         that stdin is connected to a tty and nervertheless /proc/self/loginuid
+         that stdin is connected to a tty and nevertheless /proc/self/loginuid
          contains the value (uid_t)(-1).  In this situation, getlogin() and
          getlogin_r() fail; this is expected.  */
       bool loginuid_undefined = false;
diff --git a/tests/test-intprops.c b/tests/test-intprops.c
index 5785706c08..3d995c1104 100644
--- a/tests/test-intprops.c
+++ b/tests/test-intprops.c
@@ -173,7 +173,7 @@ main (void)
      INT_<op>_OVERFLOW tests, so define macros to do both.  OP is the
      operation, OPNAME its symbolic name, A and B its operands, T the
      result type, V the overflow flag, and VRES the result if V and if
-     two's complement.  CHECK_BINOP is for most binary operatinos,
+     two's complement.  CHECK_BINOP is for most binary operations,
      CHECK_SBINOP for binary +, -, * when the result type is signed,
      and CHECK_UNOP for unary operations.  */
   #define CHECK_BINOP(op, opname, a, b, t, v, vres)                       \
diff --git a/tests/test-pthread-tss.c b/tests/test-pthread-tss.c
index 513e142d51..0caf475e54 100644
--- a/tests/test-pthread-tss.c
+++ b/tests/test-pthread-tss.c
@@ -423,7 +423,7 @@ test_tss_dtorcheck2 (void)
 #undef THREAD_COUNT
 
 
-/* --- Test thread-local storage with with races between init and destroy --- */
+/* --- Test thread-local storage with races between init and destroy --- */
 
 /* Number of simultaneous threads.  */
 #if defined __ANDROID__
diff --git a/tests/test-sigsegv-catch-segv1.c b/tests/test-sigsegv-catch-segv1.c
index 55effac67c..b1a3f666f4 100644
--- a/tests/test-sigsegv-catch-segv1.c
+++ b/tests/test-sigsegv-catch-segv1.c
@@ -79,7 +79,7 @@ main ()
   prot_unwritable = PROT_READ;
 # endif
 
-  /* Setup some mmaped memory.  */
+  /* Setup some mmapped memory.  */
   p = mmap_zeromap ((void *) 0x12340000, 0x4000);
   if (p == (void *)(-1))
     {
diff --git a/tests/test-sigsegv-catch-segv2.c b/tests/test-sigsegv-catch-segv2.c
index 1628f1a0de..f2781b9f1b 100644
--- a/tests/test-sigsegv-catch-segv2.c
+++ b/tests/test-sigsegv-catch-segv2.c
@@ -100,7 +100,7 @@ main ()
   prot_unwritable = PROT_READ;
 # endif
 
-  /* Setup some mmaped memory.  */
+  /* Setup some mmapped memory.  */
   p = mmap_zeromap ((void *) 0x12340000, 0x4000);
   if (p == (void *)(-1))
     {
diff --git a/tests/test-sigsegv-catch-stackoverflow2.c b/tests/test-sigsegv-catch-stackoverflow2.c
index 73309386aa..f6dc32626f 100644
--- a/tests/test-sigsegv-catch-stackoverflow2.c
+++ b/tests/test-sigsegv-catch-stackoverflow2.c
@@ -148,7 +148,7 @@ main ()
   prot_unwritable = PROT_READ;
 # endif
 
-  /* Setup some mmaped memory.  */
+  /* Setup some mmapped memory.  */
   p = mmap_zeromap ((void *) 0x12340000, 0x4000);
   if (p == (void *)(-1))
     {
diff --git a/tests/test-tls.c b/tests/test-tls.c
index 2b0a33ec5c..6a59a65ab0 100644
--- a/tests/test-tls.c
+++ b/tests/test-tls.c
@@ -403,7 +403,7 @@ test_tls_dtorcheck2 (void)
 #undef THREAD_COUNT
 
 
-/* --- Test thread-local storage with with races between init and destroy --- */
+/* --- Test thread-local storage with races between init and destroy --- */
 
 /* Number of simultaneous threads.  */
 #define THREAD_COUNT 10
diff --git a/tests/test-tss.c b/tests/test-tss.c
index ae17844ee5..9d1db0249a 100644
--- a/tests/test-tss.c
+++ b/tests/test-tss.c
@@ -408,7 +408,7 @@ test_tss_dtorcheck2 (void)
 #undef THREAD_COUNT
 
 
-/* --- Test thread-local storage with with races between init and destroy --- */
+/* --- Test thread-local storage with races between init and destroy --- */
 
 /* Number of simultaneous threads.  */
 #define THREAD_COUNT 10
diff --git a/top/bootstrap-funclib.sh b/top/bootstrap-funclib.sh
index 1d22eed7cc..12b668c46d 100644
--- a/top/bootstrap-funclib.sh
+++ b/top/bootstrap-funclib.sh
@@ -303,7 +303,7 @@ check_versions() {
     # Handle the still-experimental Automake-NG programs specially.
     # They remain named as the mainstream Automake programs ("automake",
     # and "aclocal") to avoid gratuitous incompatibilities with
-    # pre-existing usages (by, say, autoreconf, or custom autogen.sh
+    # preexisting usages (by, say, autoreconf, or custom autogen.sh
     # scripts), but correctly identify themselves (as being part of
     # "GNU automake-ng") when asked their version.
     case $app in
diff --git a/top/gitsub.sh b/top/gitsub.sh
index 3373c0c8b4..32f2c644cd 100755
--- a/top/gitsub.sh
+++ b/top/gitsub.sh
@@ -49,7 +49,7 @@
 #      subdirectory, let's call it a "subcheckout") are:
 #        - The simplicity: you are conceptually always using the newest revision
 #          of the dependency package.
-#        - You don't have to remember to periodially upgrade the dependency.
+#        - You don't have to remember to periodically upgrade the dependency.
 #          Upgrading the dependency is an implicit operation.
 
 # This program is meant to be copied to the top-level directory of the package,
diff --git a/top/maint.mk b/top/maint.mk
index 12004f9be1..598c4939a6 100644
--- a/top/maint.mk
+++ b/top/maint.mk
@@ -1377,7 +1377,7 @@ sc_unportable_grep_q:
 	@prohibit='grep -q' halt="unportable 'grep -q', use >/dev/null instead" \
 	  $(_sc_search_regexp)
 
-# The GNU Codying standards says that README should refer to both
+# The GNU Coding standards say that README should refer to both
 # INSTALL and the file that contains the copying conditions.  This
 # shall be COPYING for GPL and COPYING.LESSER for LGPL.
 

Reply via email to
diff --git a/tests/test-execute-main.c b/tests/test-execute-main.c
index cb799cf883..cdbb5bd761 100644
--- a/tests/test-execute-main.c
+++ b/tests/test-execute-main.c
@@ -109,8 +109,8 @@ main (int argc, char *argv[])
       break;
     case 1:
       {
-        /* Check an invocation of a non-existent program.  */
-        const char *prog_argv[3] = { "./non-existent", NULL };
+        /* Check an invocation of a nonexistent program.  */
+        const char *prog_argv[3] = { "./nonexistent", NULL };
         int ret = execute (progname, prog_argv[0], prog_argv, NULL,
                            false, false, false, false, true, false, NULL);
         ASSERT (ret == 127);